# Config Files

## Test certificates

The certificates in this directory (i.e., server-{cert,key}.pem, client-{cert,key}.pem) are used to test TLS authentication in HVAC. Do not reuse them for any other purposes. New certificates can be generated through the use of `tests/scripts/generate_test_cert.sh` when required.
